# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-IPC-System-Simple
Version:	1.30
Release:	10.%{__distinit}%{__distvers}
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
Summary:	Run commands simply, with detailed diagnostics
URL:		https://metacpan.org/release/IPC-System-Simple
Source0:	https://cpan.metacpan.org/modules/by-module/IPC/IPC-System-Simple-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(Config)
BuildRequires:	perl(constant)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(List::Util)
BuildRequires:	perl(POSIX)
BuildRequires:	perl(re)
BuildRequires:	perl(Scalar::Util)
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(File::Basename)
BuildRequires:	perl(Test)
BuildRequires:	perl(Test::More)
# Optional Tests
BuildRequires:	perl(BSD::Resource)
BuildRequires:	perl(Test::NoWarnings)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

%description
Calling Perl's in-built 'system()' function is easy; determining if it
was successful is _hard_. Let's face it, '$?' isn't the nicest variable
in the world to play with, and even if you _do_ check it, producing a
well-formatted error string takes a lot of work. 'IPC::System::Simple'
takes the hard work out of calling external commands. In fact, if you
want to be really lazy, you can just write:

    use IPC::System::Simple qw(system);

and all of your "system" commands will either succeed (run to completion and
return a zero exit value), or die with rich diagnostic messages.

%prep
%setup -q -n IPC-System-Simple-%{version}

# Avoid doc-file dependencies
chmod -c -x examples/*.pl

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%license LICENSE
%doc Changes README examples/
%{perl_vendorlib}/IPC/
%{_mandir}/man3/IPC::System::Simple.3*

%changelog
* Tue Apr 25 2023 Paul Howarth <paul@city-fan.org> - 1.30-10
- Use SPDX-format license tag
- Use %%license unconditionally

* Tue Mar 24 2020 Paul Howarth <paul@city-fan.org> - 1.30-1
- Update to 1.30
  - On MSWin32, make Win32::Process a prerequisite

* Sun Mar 22 2020 Paul Howarth <paul@city-fan.org> - 1.29-1
- Update to 1.29
  - Improved handling of shell commands on Windows, which should get us closer
    to resolving Win32-related issues; there should be no change of
    functionality on Unix-like platforms
  - Better workaround for bug in perl-5.8.9 (GH#23)
  - Add t/args.t
  - Modify t/win32.t
  - Added Travis and AppVeyor configuration files
  - Eliminated use of Dist::Zilla for build, using older, but more reliable and
    better understood (by maintainer) ExtUtils::MakeMaker-based configuration
  - Move author testing to xt/ directory

* Sat Jan 25 2020 Paul Howarth <paul@city-fan.org> - 1.26-1
- Update to 1.26
  - BUILD: Update FAIL_POSIX warning message (GH#28)
  - TEST: t/07_taint.t: Use executable name as source of taintedness (GH#21)
  - OTHER: Typographic corrections (CPAN RT#60211, CPAN RT#86403)
  - Add Travis configuration

* Thu Jun  6 2019 Paul Howarth <paul@city-fan.org> - 1.25-23
- Perl 5.30 rebuild

* Wed Aug  2 2017 Paul Howarth <paul@city-fan.org> - 1.25-16
- Fix random test failures with Test::Simple ≥ 1.302065
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Drop perl(Win32*) dependency filtering needed prior to F-7

* Wed Aug 31 2016 Paul Howarth <paul@city-fan.org> - 1.25-10
- Classify buildreqs by usage
- Simplify find command using -delete
- Prefer %%global over %%define

* Thu Sep 11 2014 Paul Howarth <paul@city-fan.org> - 1.25-2
- Drop support for building with ExtUtils::MakeMaker < 6.30
- Drop %%defattr, redundant since rpm 4.4
- Use %%license where possible

* Sun Oct 20 2013 Paul Howarth <paul@city-fan.org> - 1.25-1
- Update to 1.25
  - No longer ship unrequired file Debian_CPANTS.txt (GH #7)

* Fri Oct 18 2013 Paul Howarth <paul@city-fan.org> - 1.24-1
- Update to 1.24
  - No longer mark BSD::Resource as required (GH #6)
  - Skip core-dump tests on OS X; they're not as straightforward as the test
    script would like (GH #5)

* Wed Oct  9 2013 Paul Howarth <paul@city-fan.org> - 1.23-1
- Update to 1.23
  - Silence "Statement unlikely to be reached" warning
  - Repository information fix, and typo fixes
  - Converted to using dzil
- Specify all dependencies
- Add patch to support building with ExtUtils::MakeMaker < 6.30

* Thu Jul 18 2013 Paul Howarth <paul@city-fan.org> - 1.21-7
- Perl 5.18 rebuild

* Fri Jul  5 2013 Paul Howarth <paul@city-fan.org> - 1.21-6
- Don't run the Perl::Critic or Kwalitee tests when bootstrapping

* Sat Jul 14 2012 Paul Howarth <paul@city-fan.org> - 1.21-5
- BR: perl(constant), perl(Cwd), perl(Exporter) and perl(File::Path)
- drop BR: perl(Config) and perl(File::Basename) - not dual-lived
- specify version requirements for Test::Pod and Test::Pod::Coverage
- don't need to remove empty directories from the buildroot
- drop support for old distributions prior to FC-3:
  - BR: perl(Test::Perl::Critic) unconditionally
  - don't need to define %%{perl_vendorlib}
  - use DESTDIR rather than PERL_INSTALL_ROOT

* Mon Jun 27 2011 Paul Howarth <paul@city-fan.org> - 1.21-4
- rebuild for perl 5.14.1 in Rawhide
- fix dist tag for CentOS 6 and Scientific Linux

* Wed Mar 23 2011 Paul Howarth <paul@city-fan.org> - 1.21-3
- unconditionally BR: perl(Test::Kwalitee)

* Tue Mar 22 2011 Paul Howarth <paul@city-fan.org> - 1.21-2
- BR: perl(Test::Kwalitee)
- nobody else likes macros for commands

* Tue Feb  8 2011 Paul Howarth <paul@city-fan.org> - 1.21-1
- update to 1.21 (mainly fixes for tests under Windows)
- enable author tests

* Mon Dec 20 2010 Marcela Maslanova <mmaslano@redhat.com> - 1.18-5
- rebuild to fix problems with vendorarch/lib (#661697)

* Sun May 02 2010 Marcela Maslanova <mmaslano@redhat.com> - 1.18-4
- mass rebuild with perl 5.12.0

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 1.18-3
- rebuild against perl 5.10.1

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.18-2
- rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Mar 05 2009 Chris Weyl <cweyl@alumni.drew.edu> - 1.18-1
- submission

* Thu Mar 05 2009 Chris Weyl <cweyl@alumni.drew.edu> - 1.18-0
- initial RPM packaging
- generated with cpan2dist (CPANPLUS::Dist::RPM version 0.0.8)
